Release Notes for STM32F105/7xx and STM32F2xx USB Device Library

Back to Release page
# Release Notes for STM32F105/7xx and STM32F2xx USB Device Library Copyright 2011 STMicroelectronics
## Contents STM32F105/7xx and STM32F2xx USB Device Library update History License ## STM32F105/7xx and STM32F2xx USB Device Library update History ### V1.0.0 / 22-July-2011 Main Changes First official version for STM32F105/7xx and STM32F2xx devices ## License The use of this STM32 software is governed by the terms and conditions of the License Agreement "MCD-ST Liberty SW License Agreement 20Jul2011 v0.1.pdf" available in the root of this package. For complete documentation on STM32(CORTEX M3) 32-Bit Microcontrollers visit www.st.com/STM32